@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -204,7 +203,7 @@ gsd_ldsm_dialog_init (GsdLdsmDialog *dialog)
         /* Set up all the window stuff here */
         gtk_window_set_title (GTK_WINDOW (dialog), _("Low Disk Space"));
         gtk_window_set_icon_name (GTK_WINDOW (dialog), 
-                                  GTK_STOCK_DIALOG_WARNING);
+                                  "dialog-warning");
         gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
         gtk_window_set_position (GTK_WINDOW (dialog), GTK_WIN_POS_CENTER);
         gtk_window_set_urgency_hint (GTK_WINDOW (dialog), TRUE);
@@ -212,7 +211,7 @@ gsd_ldsm_dialog_init (GsdLdsmDialog *dialog)
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);
 
         /* Create the image */
-        image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
+        image = gtk_image_new_from_icon_name ("dialog-warning", GTK_ICON_SIZE_DIALOG);
         gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
 
         /* Create the labels */
@@ -415,7 +414,7 @@ gsd_ldsm_dialog_new (gboolean     other_usable_partitions,
 {
         GsdLdsmDialog *dialog;
         GtkWidget *button_empty_trash, *button_ignore, *button_analyze;
-        GtkWidget *empty_trash_image, *analyze_image, *ignore_image;
+        GtkWidget *empty_trash_image, *analyze_image;
         gchar *primary_text, *primary_text_markup;
         const gchar *secondary_text, *checkbutton_text;
 	
@@ -433,7 +432,7 @@ gsd_ldsm_dialog_new (gboolean     other_usable_partitions,
                 button_empty_trash = gtk_dialog_add_button (GTK_DIALOG (dialog),
                                                             _("Empty Trash"),
                                                             GSD_LDSM_DIALOG_RESPONSE_EMPTY_TRASH);
-                empty_trash_image = gtk_image_new_from_stock (GTK_STOCK_CLEAR, GTK_ICON_SIZE_BUTTON);
+                empty_trash_image = gtk_image_new_from_icon_name ("edit-clear", GTK_ICON_SIZE_BUTTON);
                 gtk_button_set_image (GTK_BUTTON (button_empty_trash), empty_trash_image);
         }
 	
@@ -448,9 +447,7 @@ gsd_ldsm_dialog_new (gboolean     other_usable_partitions,
         button_ignore = gtk_dialog_add_button (GTK_DIALOG (dialog), 
                                                _("Ignore"), 
                                                GTK_RESPONSE_CANCEL);
-        ignore_image = gtk_image_new_from_stock (GTK_STOCK_CANCEL, GTK_ICON_SIZE_BUTTON);
-        gtk_button_set_image (GTK_BUTTON (button_ignore), ignore_image);
-	
+
         gtk_widget_grab_default (button_ignore);
 	
         /* Set the label text */	
