@@ -35,10 +35,8 @@
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 #include <gdk/gdk.h>
-#include <gdk/gdkx.h>
 #include <gtk/gtk.h>
 #include <libupower-glib/upower.h>
-#include <X11/Xatom.h>
 
 #define GNOME_DESKTOP_USE_UNSTABLE_API
 
@@ -124,8 +122,6 @@ static void     gsd_xrandr_manager_class_init  (GsdXrandrManagerClass *klass);
 static void     gsd_xrandr_manager_init        (GsdXrandrManager      *xrandr_manager);
 static void     gsd_xrandr_manager_finalize    (GObject             *object);
 
-static void error_message (GsdXrandrManager *mgr, const char *primary_text, GError *error_to_display, const char *secondary_text);
-
 static void get_allowed_rotations_for_output (GnomeRRConfig *config,
                                               GnomeRRScreen *rr_screen,
                                               GnomeRROutputInfo *output,
@@ -930,15 +926,6 @@ generate_fn_f7_configs (GsdXrandrManager *mgr)
         }
 }
 
-static void
-error_message (GsdXrandrManager *mgr, const char *primary_text, GError *error_to_display, const char *secondary_text)
-{
-    g_warning("%s\n%s\n%s",
-              primary_text? primary_text : "",
-              secondary_text? secondary_text : "",
-              error_to_display? error_to_display->message : "");
-}
-
 static void
 handle_fn_f7 (GsdXrandrManager *mgr, gint64 timestamp)
 {
